@@ -14,10 +14,10 @@ from .warnings import IgnoredBnglFileContentWarning
 from biosimulators_utils.combine.exec import exec_sedml_docs_in_archive
 from biosimulators_utils.log.data_model import CombineArchiveLog, TaskLog  # noqa: F401
 from biosimulators_utils.plot.data_model import PlotFormat  # noqa: F401
-from biosimulators_utils.report.data_model import ReportFormat, DataGeneratorVariableResults  # noqa: F401
+from biosimulators_utils.report.data_model import ReportFormat, VariableResults  # noqa: F401
 from biosimulators_utils.sedml import validation
 from biosimulators_utils.sedml.data_model import (Task, ModelLanguage, ModelAttributeChange,  # noqa: F401
-                                                  UniformTimeCourseSimulation, DataGeneratorVariable)
+                                                  UniformTimeCourseSimulation, Variable)
 from biosimulators_utils.sedml.exec import exec_sed_doc
 import functools
 import warnings
@@ -61,13 +61,13 @@ def exec_sed_task(sed_task, variables, log=None):
 
     Args:
        sed_task (:obj:`Task`): task
-       variables (:obj:`list` of :obj:`DataGeneratorVariable`): variables that should be recorded
+       variables (:obj:`list` of :obj:`Variable`): variables that should be recorded
        log (:obj:`TaskLog`, optional): log for the task
 
     Returns:
         :obj:`tuple`:
 
-            :obj:`DataGeneratorVariableResults`: results of variables
+            :obj:`VariableResults`: results of variables
             :obj:`TaskLog`: log
     """
     """ Validate task
@@ -98,6 +98,7 @@ def exec_sed_task(sed_task, variables, log=None):
     validation.validate_task(sed_task)
     validation.validate_model_language(sed_task.model.language, ModelLanguage.BNGL)
     validation.validate_model_change_types(sed_task.model.changes, (ModelAttributeChange, ))
+    validation.validate_model_changes(sed_task.model.changes)
     validation.validate_simulation_type(sed_task.simulation, (UniformTimeCourseSimulation, ))
     validation.validate_uniform_time_course_simulation(sed_task.simulation)
     validation.validate_data_generator_variables(variables)
